# favico.js
More info [here](http://lab.ejci.net/favico.js/).


Author [Miroslav Magda](http://blog.ejci.net)
Version 0.3.9

Contributors:
[Serge Barysiuk](https://github.com/sbarysiuk),
[pissflaps](https://github.com/pissflaps),
[Yaroslav Yakovlev](https://github.com/yaroslavya),
[LoicMahieu](https://github.com/LoicMahieu),
[Renan Gonçalves](https://github.com/renan),
[Adam Savitzky](https://github.com/adambom),
[Jory Graham](https://github.com/jory)

```javascript

```

## License
All code is open source and dual licensed under GPL and MIT. Check the individual licenses for more information.

### Change log
#### 0.3.10
* bugfixes

#### 0.3.9
* bugfixes

#### 0.3.8
* bumped version to add it to npm

#### 0.3.7
* bugfixes & support for font icons (fontawesome)

#### 0.3.6
* bugfixes

#### 0.3.4
* new option for position

#### 0.3.3
* bugfixes

#### 0.3.2
* support for badge numbers bigger than 999

#### 0.3.1
* bugfix if <link type="icon"...> is missing

#### 0.3.0
* font options (font family, font style)
* badge count more than 9
* badge positions

#### 0.2.2
* AMD - CommonJS compatibility

#### 0.2.1
* Fixed console.log bug
* registered to bower

#### 0.2.0
* Webcam support for Opera and Firefox
* Improved performance for Opera and Firefox
* New animation type popfade
* Code cleanup

#### 0.1.1
* Improving performance in chrome

#### 0.1.0
* proof of concept
